;; Generated package description from geiser-guile.el  -*- no-byte-compile: t -*-
(define-package "geiser-guile" "0.28.3" "Guile and Geiser talk to each other" '((emacs "26.1") (transient "0.3") (geiser "0.28.1")) :commit "a0f111f8dedd31c593c4ed12c0b99745f3c1340f" :authors '(("Jose Antonio Ortega Ruiz" . "(jao@gnu.org)")) :maintainer '("Jose Antonio Ortega Ruiz" . "(jao@gnu.org)") :keywords '("languages" "guile" "scheme" "geiser") :url "https://gitlab.com/emacs-geiser/guile")
